@@ -1,4 +1,3 @@
-import os
 from django.conf import settings
 from django.utils.importlib import import_module
 from django.core.urlresolvers import RegexURLResolver, RegexURLPattern
@@ -126,7 +125,12 @@ class UrlParser(object):
                     continue
 
                 pref = prefix + pattern.regex.pattern
-                pattern_list.extend(self.__flatten_patterns_tree__(pattern.url_patterns, pref, filter_path=filter_path))
+                pattern_list.extend(self.__flatten_patterns_tree__(
+                    pattern.url_patterns,
+                    pref,
+                    filter_path=filter_path,
+                    exclude_namespaces=exclude_namespaces,
+                ))
 
         return pattern_list
 
